@@ -47,7 +47,6 @@ class ApplicationConfigurator():
 
 class KafkaConfig(object):
     def __init__(self, kafka_brokers, json=False):
-        print(kafka_brokers)
         self.json = json
         if not json:
             self.producer = KafkaProducer(
@@ -70,20 +69,12 @@ class FerrisKafkaLoggingHandler(StreamHandler):
 
     def __init__(self,topic='ferris.logs'):
         StreamHandler.__init__(self)
+        environment = ApplicationConfigurator().get('ferris.env')
+        broker_url = f"{environment['KAFKA_BOOTSTRAP_SERVER']}:{environment['KAFKA_PORT']}"
         self.topic = topic
         # Kafka Broker Configuration
         self.kafka_broker = KafkaConfig(broker_url)
 
-        STRING_FORMAT = '''{
-        "Levelname":       "levelname",
-        "Name":            "name",
-        "Asctime":         "asctime",
-        "Message":         "message"
-        }'''
-
-        formatter =  JsonFormatter(STRING_FORMAT)
-        self.setFormatter(formatter)
-
     def emit(self, record):
         msg = self.format(record)
         self.kafka_broker.send(msg, self.topic)
@@ -95,7 +86,7 @@ class MetricMessage(object):
         self.metric_value = metric_value
         if update_time == None:
             dateTimeObj = datetime.now()
-            timestampStr = dateTimeObj.strftime("%d-%b-%Y (%H:%M:%S.%f)")
+            timestampStr = dateTimeObj.strftime("%Y-%m-%dT%H:%M:%SZ")
             self.update_time = timestampStr
         else:
             self.update_time = update_time
@@ -130,7 +121,9 @@ class CloudEventsAPI():
         self.kafka_broker = KafkaConfig(broker_url)
     def send(self, event):
         event.SetEventID(uuid.uuid1().hex)
-        date_time = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
+        date_time = datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")
+
+      
         event.SetEventTime(date_time)
         s = json.dumps(event.Properties())
         self.kafka_broker.send(s, self.topic)
@@ -154,6 +147,7 @@ class ExecutionTime:
             start_time = time.perf_counter()
             result = method(*args,**kwargs)
             end_time = time.perf_counter()
+            current_time = round((end_time-start_time)*1000,4)
             total_time = round((end_time-start_time)*1000,4) # time in milliseconds 
             
             if method.__name__ in self.logtime_data:
@@ -161,9 +155,9 @@ class ExecutionTime:
                 tt = curr["total_time"]+total_time
                 count = curr["times_called"]+1
                 avg_time=round(tt/count,4) 
-                self.logtime_data[method.__name__]={'times_called':count,"total_time":tt,"average_time":avg_time}
+                self.logtime_data[method.__name__]={'times_called':count,"total_time":tt,"average_time":avg_time,"current_time":current_time}
             else:
-                self.logtime_data[method.__name__]={'times_called':1,"total_time":total_time,"average_time":total_time}
+                self.logtime_data[method.__name__]={'times_called':1,"total_time":total_time,"average_time":total_time,"current_time":current_time}
 
         return wrapper
      
